Crate simkl

Crate simkl 

Modules

anime
auth
calendar
checkin
error
images
When getting images, SIMKL asks to cache it in your app forever. The images with the same URL never change. Do not redownload the same image multiple times.
movie
pagination
pin
PIN for devices with limited UI
rate_limit
Sliding-window rate limiter for Simkl API requests.
ratings
Ratings API — two endpoints:
redirect
Redirect API — GET /redirect?to=Simkl&...
request
response
search
show
sync
user

Structs

AirInfo
Episode
Extended
By default methods are not returning additional data for movies, anime, show etc. They return minimal info you need to match in the local database. But, if you need more information just add `extended={fields}`` to the URL. Will be in lower case
MediaIds
ParseMediaTypeError
Error returned when a string cannot be parsed into a MediaType.
Rank
Rating
Ratings
Season
SeasonEpisode
StandardMediaObject

Enums

MediaType

Constants

API_URL
API URL, queries will need the following headers:
OAUTH_URL
TOKEN_URL

Functions

get_auth_url
get_extended_parameter
get_pagination_parameter
Some the endpoints are paginated. Endpoints which have 📄 Pagination will load 1 page of 10 items by default. If you want to change this, append query string ?page={page}&limit={limit} to the URL.